/****************************************************************************
 File Name  : ima2.c
 Purpose    : histogram specification
 Date	    : Aug 31,1995

GSNAKE API is jointly developed by the Information Technology Institute (ITI), Singapore, and the School of Applied Science, Nanyang Technological
University (NTU), Singapore. 

These software programs are available to the user without any license or royalty fees. Permission is hereby granted to use, copy, modify, and distribute this software and its documentation for any purpose. ITI and NTU gives no warranty, express, implied, or statuary for the software and/or documentation provided, including, without limitation, waranty of merchantibility and warranty of fitness for a particular purpose. The software provided hereunder is on an "as is"  basis, and ITI and NTU has no obligation to provide maintenance, support, updates, enhancements, or modifications.

GSNAKE API is available for any UNIX compatible system. User feedback, bugs, or software and manual suggestions should be sent via electronic mail to one of the following, who may or may not act on them as he/she desires :

		asschan@ntu.ac.sg
		kflai@iti.gov.sg
***************************************************************************/

#include "xwindow.h"
#include "gsnake.h"


void printhelp();
void getparam(int, char**,int *,float*, float*,float*, float*, float*);
void testmain(char *,int ,float, float,float, float, float);


main(int argc, char *argv[])
{
	int i, j;
	int magnify;
	float low_p, high_p, low_v,high_v,epow;
	
	low_p=0.9;
	high_p=0.95;
	low_v=0.2;
	high_v=0.9;
	epow=1.0;
	magnify =1;

	if (argc==1) printhelp();
	else {
		getparam(argc,argv,&magnify,&low_p, &high_p,&low_v,&high_v, &epow);	
		testmain(argv[1], magnify, low_p, high_p, low_v, high_v, epow);
	
		return(NOERROR);
	} /* of else */		
}


void testmain( char *imgfile,		/* input image file */
	       int blowup,		/* magnification factor */
	       float lp , float hp,	/* percentage range */
	       float lv, float hv,	/* intensity range */
	       float ep )		/* exponential power */
{   
	IMAGE myimage;

	if  ( !(myimage.read(imgfile)) ) { 
	
		printf("Displaying image .... \n\n");
		printf("Histogram Specification parameters :\n");
		printf("\n    Low Percent:%f     High Percent:%f",lp,hp);
		printf("\n    Low Value  :%f     High Value  :%f",lv,hv);
		printf("\n    Exponent   :%f     Magnification:%d",ep,blowup);
		myimage.show(blowup,2);
		myimage.condition(lp,hp,lv,hv,ep);
		printf("Displaying conditioned image ... Press enter to continue \n");
		myimage.show(blowup,1,myimage.getCol()*blowup);
		getchar();		
		xwin_close();	
	}
}

void getparam( int ac, char** av,
	       int *Mfactor,
	       float* lp, float *hp,
               float *lv, float*hv,
	       float *e_pow)
{   
	register int i;
	char *inputstr;

	for (i=2; i<ac; i++) {

		if (*(av[i]) != '-') continue;
		
		inputstr = av[i]+2;

		switch( *(av[i]+1) ) {
				
		   case 'M' :
			*Mfactor=atoi(inputstr);
			break;

		   case 'P' :
			inputstr=av[i]+3;

			switch (*(av[i]+2)) {
			   case 'l': *lp=atof(inputstr); break;
			   case 'h': *hp=atof(inputstr);break;			
			}
			break;

		   case 'V' :
			inputstr = av[i]+3;

			switch( *(av[i]+2) ) {
			   
			   case 'l' :  *lv = atof(inputstr);break;
			   case 'h' :  *hv = atof(inputstr);break;
			}
			break;

		   case 'e' :
			*e_pow=atof(inputstr);
			 break;

		    default: break;
		}
	}
}


void printhelp()
{
	printf("\n\nHistogram conditioning of image");
	printf("\n Usage :OOimg2 <image> [ option ]");
	printf("\n [ option ] ");
	printf("\n -M      :Magnification factor, default 1 ");
	printf("\n -Pl,-Ph :Low and High Percentage values for correlation");	
	printf("\n         :Default Pl = 0.9 , Ph = 0.95");
	printf("\n -Vl,-Vh :Low and High Pixel values ");
	printf("\n         :Default Vl = 0.2 , Vh = 0.9");
	printf("\n -e      :Exponential value ");
	printf("\n         :Default e = 1\n\n");
}
