/****************************************************************************
 File Name  : ima3.c
 Purpose    : 1. Cutting of image segments
	      2. Copying of images 
 Date	    : Aug 31,1995

GSNAKE API is jointly developed by the Information Technology Institute (ITI), Singapore, and the School of Applied Science, Nanyang Technological
University (NTU), Singapore. 

These software programs are available to the user without any license or royalty fees. Permission is hereby granted to use, copy, modify, and distribute this software and its documentation for any purpose. ITI and NTU gives no warranty, express, implied, or statuary for the software and/or documentation provided, including, without limitation, waranty of merchantibility and warranty of fitness for a particular purpose. The software provided hereunder is on an "as is"  basis, and ITI and NTU has no obligation to provide maintenance, support, updates, enhancements, or modifications.

GSNAKE API is available for any UNIX compatible system. User feedback, bugs, or software and manual suggestions should be sent via electronic mail to one of the following, who may or may not act on them as he/she desires :

		asschan@ntu.ac.sg
		kflai@iti.gov.sg
***************************************************************************/


#include "gsnake.h"
#include "xwindow.h"

void testmain(char *,char *,int );
void printhelp();
void getparam(int, char **, int *, char **);


main(int argc,char **argv)
{
	char *output = NULL;
	int magnify = 1;
		
	if (argc==1) printhelp();
	else {
		getparam(argc,argv,&magnify,&output);
		testmain(argv[1],output,magnify);		
		return(0);
	}	
}

void testmain( char *imgfile,	/* input image file */
	       char *outfile,	/* output image file */
	       int mag )	/* magnification factor */
{
	IMAGE test1;
	IMAGE *test2,*test3;
	
	int sx, sy, length, height;
	
	/* Read image file */
	if  (test1.read(imgfile) ) exit(-1);
	
	printf("Showing test1 : %s",imgfile);
	test1.show(mag);
	
	/* Using X windows to select an image segment */
	xwin_SelRegion(	&sx,&sy,&length,&height);
	test2 = test1.cut(sx/mag ,sy/mag ,length/mag, height/mag);
	
	/* Copy image*/
	test3 = test2->copy();
	
	/* Show images in line */
	printf("\nShowing cut image and copied image ");
	test2->show(mag,2);
	test3->show(mag,1,test2->getCol());
	printf("\nPress enter to continue...");
	getchar();
	
	if (outfile) {
		printf("\nWriting to file %s",outfile);
		test3->write(outfile); 
	}

	printf("End of test..");
	xwin_close();
}


void getparam( int ac, char **av, 
	       int *Mfactor, 
	       char **tempfile )
{   
	register int i;
	char *inputstr;

	for (i=2; i<ac; i++) {

		if (*(av[i]) != '-') continue;
		
		inputstr = av[i]+2;

		switch( *(av[i]+1) ) {
				
		   case 'M' :
			*Mfactor=atoi(inputstr);
			break;

		   case 'O' :
		   	 *tempfile=inputstr;
			 break;

		    default: break;
		}
	}
}

void printhelp()
{
	printf("\n\nCutting of image segment  ");
	printf("\n Usage :OOima3 <image> [ option ] ");
	printf("\n [ option ] ");
	printf("\n -M    :Magnification factor, default 1 ");
	printf("\n -O    :Output image file\n\n");
}
