/****************************************************************************
 File Name  : sna1.c
 Purpose    : internal energy calculation
 Date	    : Aug 31,1995

GSNAKE API is jointly developed by the Information Technology Institute (ITI), Singapore, and the School of Applied Science, Nanyang Technological
University (NTU), Singapore. 

These software programs are available to the user without any license or royalty fees. Permission is hereby granted to use, copy, modify, and distribute this software and its documentation for any purpose. ITI and NTU gives no warranty, express, implied, or statuary for the software and/or documentation provided, including, without limitation, waranty of merchantibility and warranty of fitness for a particular purpose. The software provided hereunder is on an "as is"  basis, and ITI and NTU has no obligation to provide maintenance, support, updates, enhancements, or modifications.

GSNAKE API is available for any UNIX compatible system. User feedback, bugs, or software and manual suggestions should be sent via electronic mail to one of the following, who may or may not act on them as he/she desires :

		asschan@ntu.ac.sg
		kflai@iti.gov.sg
***************************************************************************/

#include "gsnake.h"
#include "xwindow.h"

void getparam(int ac, char **av, int *Mfactor);
void testmain(char *imgfile, int mag);
void printhelp();

main( int argc, char **argv )
{
	int level = 2;
	int magnify = 1;
	char *outfile = NULL;

	if (argc==1) printhelp();
	else {
		getparam(argc,argv,&magnify);			
		testmain(argv[1],magnify);
		return(0);
	}	
}         


void testmain( char *confile,	/* standard contour file */
	       int mag )	/* magnification factor */
{
	SNAXEL *sptr;		/* SNAXEL object */
	CONTOUR mycontour;	/* CONTOUR object */
	double l_inf;           /* infinity norm */
        double meanrow,		/* mean position of snaxel */
	       meancol;
	double avglen;		/* average length of snaxel */
	double Eint;		/* Internal energy */
	double cg_row,		/* center of gravity (CG) */
	       cg_col;
	register short i;
		
	/* Read and show the contour */
	if ( mycontour.read( confile ) )	exit( -1 );

	mycontour.display(mag);
	
	/* Compute the average distance between snaxels and CG*/
	mycontour.computeCG();
	avglen = mycontour.computeAvgLength();
	cg_row = mycontour.getCgRow();
	cg_col = mycontour.getCgCol();
	printf("\nCentre of gravity at row %d col %d\n",
				ROUNDOFF( cg_row ), ROUNDOFF( cg_col ));
		
	mycontour.imageCentered();

	/* Calculating the internal energy for each snaxel */
	for (i=0, sptr=mycontour.getHead(); sptr; sptr=sptr->getNext(),i++) {

        	if ( fabs(sptr->getAlpha() ) < VERY_SMALL &&
             		fabs(sptr->getBeta() )  < VERY_SMALL )
                	Eint = 1.0;

        	/* compute shape coeff. (alpha & beta) with infinity norm */
        	sptr->meanPosition( mycontour.getMode(), cg_row, cg_col,
                		  mycontour.getHead(), mycontour.getTail(),
                		  &meanrow, &meancol);
        	l_inf = MAX( fabs( meanrow - sptr->getRow() ),
                             fabs( meancol - sptr->getCol() ) );
        	Eint =  SQR( l_inf / avglen );
		printf("\nSnaxel %d energy = %f",i,Eint);
	}

	printf("\nEnd of test.");
	printf("\nPress enter to continue.");
	getchar();
	xwin_close();
}                                                                                                                                                 

void getparam(int ac, char **av, int *Mfactor)
{   
	register int i;
	char *inputstr;

	for (i=2; i<ac; i++) {

		if (*(av[i]) != '-') continue;
			
		inputstr = av[i]+2;

		switch( *(av[i]+1) ) {
				
		   case 'M' :
			*Mfactor=atoi(inputstr);
			break;			
	
		}
	}
}

void printhelp()
{
	printf("\n\nInternal energy calculation by snaxel");
	printf("\n Usage :OOsna1 <contour> [ option ] ");
	printf("\n [ option ] ");
	printf("\n -M    :Magnification factor, default 1\n\n");
}
