/****************************************************************************
 File Name  : imgpyramid.c
 Purpose    : to generate pyramid images
 Release    : Version 1.0
 Date	    : Aug 31,1995

GSNAKE API is jointly developed by the Information Technology Institute (ITI), Singapore, and the School of Applied Science, Nanyang Technological
University (NTU), Singapore. 

These software programs are available to the user without any license or royalty fees. Permission is hereby granted to use, copy, modify, and distribute this software and its documentation for any purpose. ITI and NTU gives no warranty, express, implied, or statuary for the software and/or documentation provided, including, without limitation, waranty of merchantibility and warranty of fitness for a particular purpose. The software provided hereunder is on an "as is"  basis, and ITI and NTU has no obligation to provide maintenance, support, updates, enhancements, or modifications.

GSNAKE API is available for any UNIX compatible system. User feedback, bugs, or software and manual suggestions should be sent via electronic mail to one of the following, who may or may not act on them as he/she desires :

		asschan@ntu.ac.sg
		kflai@iti.gov.sg
***************************************************************************/

#include "xwindow.h"
#include "gsnake.h"

void getparam(int ac, char** av,int *Lvl,int *Mfactor, float* lp, float *hp, float *lv, float*hv, float *e_pow);   

void printHelp();


main(int argc, char **argv)
{
	PYRAMID mypyramid;	/* pyramid object */
	
	int level	= 2;	/* Gaussian pyramid level */
	int mag		= 1;	/* magnification factor */
	float low_p	= 0.9;	/* low percentage value */
	float high_p	= 0.95;	/* high percentage value */
	float low_v	= 0.2;	/* low intensity value */
	float high_v	= 0.9;	/* high intensity value */
	float e_pow	= 1;	/* exponential power */

	register short i, j;
	char Title[30]="imgpym : ";
  	
	if (argc==1) 	   printHelp();

	else {
				
	   getparam( argc, argv, &level, &mag, &low_p, &high_p,
		     &low_v, &high_v, &e_pow);

	   if  (!mypyramid.putRawImg(argv[1])) {  	

		xwin_setTitle(strcat(Title,argv[1]));
		printf("Histogram Specification parameters :\n");
		printf("\n\tLow Percent:%f\tHigh Percent:%f",low_p,high_p);
		printf("\n\tLow Value  :%f\tHigh Value  :%f",low_v,high_v);
		printf("\n\tExponent   :%f\tMagnification:%d\n\n",e_pow,mag);
                mypyramid.generate(level,1,low_p,high_p,low_v,high_v,e_pow);
		mypyramid.show(mag,level);
		printf("\n\nPress enter to end ... ");
		getchar();
		xwin_close();
	   }
	}
}


void getparam( int ac, char** av,
	       int *Lvl,		/* Gaussian pyramid level */
	       int *Mfactor,		/* magnification factor */
	       float* lp, float *hp, 	/* percentage range */
	       float *lv, float*hv,	/* intensity range */
	       float *e_pow )		/* exponential power */
{   
	register int i;
	char *inputstr;

	for (i=2; i<ac; i++) {

	    if ( *av[i] != '-' )
		continue; /* illegal input */

		inputstr = av[i]+2;

		switch( *(av[i]+1) ) {

		   case 'L' :

			*Lvl= atoi(inputstr);
			break;
				
		   case 'M' :
			*Mfactor=atoi(inputstr);
			break;

		   case 'P' :
			inputstr=av[i]+3;

			switch (*(av[i]+2)) {
			   case 'l': *lp=atof(inputstr); break;
			   case 'h': *hp=atof(inputstr);break;			
			}
			break;

		   case 'V' :

			inputstr = av[i]+3;

			switch( *(av[i]+2) ) {
			   
			   case 'l' :  *lv = atof(inputstr);break;
			   case 'h' :  *hv = atof(inputstr);break;
			}
			break;

		   case 'E' :
		
			*e_pow=atof(inputstr);
			 break;
	

		    default: break;
		}
	}
}


void printHelp()
{		
	printf("\n\n Pyramid Generation of Image:");
	printf("\n\n Usage: imgpym <image> -[option]");
	printf("\n [ option ]");	
	printf("\n L    :Level of pyramid generation. Default = 2");
	printf("\n M    :Magnification factor. Default = 1");
	printf("\n Pl,Ph:Low and HIgh Percentage values for correlation");
	printf("\n      :Default values 0.9 and 0.95");
	printf("\n Vl,Vh:Low and High Pixel values ");
	printf("\n      :Default values 0.2 and 0.9\n\n");
}
